@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2005, 2007, 2010-2012, 2014-2017 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2021 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -31,7 +30,6 @@ extern void * mu_body_get_owner   (mu_body_t);
 extern int mu_body_is_modified    (mu_body_t);
 extern int mu_body_clear_modified (mu_body_t);
 
-extern int mu_body_get_stream     (mu_body_t, mu_stream_t *) MU_DEPRECATED;
 extern int mu_body_get_streamref  (mu_body_t body, mu_stream_t *pstream);
 extern int mu_body_set_stream     (mu_body_t, mu_stream_t, void *owner);
 extern int mu_body_set_get_stream (mu_body_t,
@@ -44,6 +42,8 @@ extern int mu_body_set_size       (mu_body_t,
 extern int mu_body_lines          (mu_body_t, size_t *);
 extern int mu_body_set_lines      (mu_body_t,
 				int (*_lines) (mu_body_t, size_t*), void *owner);
+extern void mu_body_ref (mu_body_t body);
+extern void mu_body_unref (mu_body_t body);
 
 #ifdef __cplusplus
 }
