@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2004-2005, 2007, 2010-2012, 2014-2015 Free Software
-   Foundation, Inc.
+   Copyright (C) 2004-2021 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,7 +19,6 @@
 #define _MAILUTILS_DAEMON_H
 
 #include <mailutils/types.h>
-#include <mailutils/gocs.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -30,10 +28,9 @@ extern "C" {
 #define MODE_INTERACTIVE 0
 #define MODE_DAEMON 1
 
-extern int  mu_daemon_create_pidfile  (const char *);
-extern void mu_daemon_remove_pidfile  (void);
-
-extern struct mu_gocs_daemon mu_gocs_daemon;  
+int  mu_daemon_create_pidfile  (const char *);
+void mu_daemon_remove_pidfile  (void);
+int mu_daemon (void);
 
 #ifdef __cplusplus
 }
